summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEmmanuele Bassi <ebassi@gnome.org>2022-09-09 23:19:04 +0100
committerEmmanuele Bassi <ebassi@gnome.org>2022-09-10 00:16:12 +0100
commitd6597098f1cf6d99d56c633a9822892c9f61687c (patch)
tree21b6abce844473fea5406fe0457338acd1d819eb
parentef9b844c7f9b8f9b0242e5ed56bd387cbefa3cbd (diff)
downloadgtk+-d6597098f1cf6d99d56c633a9822892c9f61687c.tar.gz
ci: Re-sync the style check with GLib
-rwxr-xr-x.gitlab-ci/run-style-check-diff.sh44
1 files changed, 29 insertions, 15 deletions
diff --git a/.gitlab-ci/run-style-check-diff.sh b/.gitlab-ci/run-style-check-diff.sh
index a69fd77308..b1be379033 100755
--- a/.gitlab-ci/run-style-check-diff.sh
+++ b/.gitlab-ci/run-style-check-diff.sh
@@ -2,25 +2,39 @@
set -e
-# We need to add a new remote for the upstream main, since this script could
-# be running in a personal fork of the repository which has out of date branches.
-if [ "${CI_PROJECT_NAMESPACE}" != "GNOME" ]; then
- echo "Retrieving the current upstream repository from ${CI_PROJECT_NAMESPACE}/${CI_PROJECT_NAME}..."
+ancestor_horizon=31 # days (one month)
+
+# We need to add a new remote for the upstream target branch, since this script
+# could be running in a personal fork of the repository which has out of date
+# branches.
+#
+# Limit the fetch to a certain date horizon to limit the amount of data we get.
+# If the branch was forked from origin/main before this horizon, it should
+# probably be rebased.
+if ! git ls-remote --exit-code upstream >/dev/null 2>&1 ; then
git remote add upstream https://gitlab.gnome.org/GNOME/gtk.git
- git fetch upstream
- ORIGIN="upstream"
-else
- echo "Reusing the existing repository on ${CI_PROJECT_NAMESPACE}/${CI_PROJECT_NAME}"
- ORIGIN="origin"
fi
+git fetch --shallow-since="$(date --date="${ancestor_horizon} days ago" +%Y-%m-%d)" upstream
# Work out the newest common ancestor between the detached HEAD that this CI job
# has checked out, and the upstream target branch (which will typically be
-# `upstream/main` or `upstream/gtk-3-24`).
-#
-# `${CI_MERGE_REQUEST_TARGET_BRANCH_NAME}` is only defined if we’re running in
-# a merge request pipeline; fall back to `${CI_DEFAULT_BRANCH}` otherwise.
-newest_common_ancestor_sha=$(diff --old-line-format='' --new-line-format='' <(git rev-list --first-parent "${ORIGIN}/${CI_MERGE_REQUEST_TARGET_BRANCH_NAME:-${CI_DEFAULT_BRANCH}}") <(git rev-list --first-parent HEAD) | head -1)
+# `upstream/main` or `upstream/glib-2-62`).
+# `${CI_MERGE_REQUEST_TARGET_BRANCH_NAME}` or `${CI_MERGE_REQUEST_SOURCE_BRANCH_NAME}`
+# are only defined if we’re running in a merge request pipeline,
+# fall back to `${CI_DEFAULT_BRANCH}` or `${CI_COMMIT_BRANCH}` respectively
+# otherwise.
+
+source_branch="${CI_MERGE_REQUEST_SOURCE_BRANCH_NAME:-${CI_COMMIT_BRANCH}}"
+git fetch --shallow-since="$(date --date="${ancestor_horizon} days ago" +%Y-%m-%d)" origin "${source_branch}"
+
+newest_common_ancestor_sha=$(diff --old-line-format='' --new-line-format='' <(git rev-list --first-parent "upstream/${CI_MERGE_REQUEST_TARGET_BRANCH_NAME:-${CI_DEFAULT_BRANCH}}") <(git rev-list --first-parent "origin/${source_branch}") | head -1)
+if [ -z "${newest_common_ancestor_sha}" ]; then
+ echo "Couldn’t find common ancestor with upstream main branch. This typically"
+ echo "happens if you branched from main a long time ago. Please update"
+ echo "your clone, rebase, and re-push your branch."
+ exit 1
+fi
+
git diff -U0 --no-color "${newest_common_ancestor_sha}" | .gitlab-ci/clang-format-diff.py -binary "clang-format" -p1
exit_status=$?
@@ -36,7 +50,7 @@ exit_status=$?
echo ""
echo "Note that clang-format output is advisory and cannot always match the"
echo "GTK coding style, documented at:"
-echo " https://gitlab.gnome.org/GNOME/gtk/blob/main/docs/CODING-STYLE"
+echo " https://gitlab.gnome.org/GNOME/gtk/blob/main/docs/CODING-STYLE.md"
echo "Warnings from this tool can be ignored in favour of the documented "
echo "coding style, or in favour of matching the style of existing"
echo "surrounding code."